pub fn load_config() -> Result<MxrConfig, ConfigError>Expand description
Load config from the default config file path, falling back to defaults.
pub fn load_config() -> Result<MxrConfig, ConfigError>Load config from the default config file path, falling back to defaults.